searchData={"items":[{"type":"module","title":"Nvir","doc":"Nvir is an environment variable loader and validator.\n\nPlease refer to the [README](README.md#basic-usage) for usage instructions.","ref":"Nvir.html"},{"type":"function","title":"Nvir.cast/2","doc":"","ref":"Nvir.html#cast/2"},{"type":"function","title":"Nvir.dotenv!/1","doc":"Loads specified env files in the system environment. Intended usage is from\n`config/runtime.exs` in your project\n\nVariables defined in the files will not override the system environment\nif they are already defined. To override the system env, please list your\nfiles under an `:override` key.\n\nFiles that do not exist are safely ignored.\n\nValid values are\n* A single binary string (a file path).\n* A list of paths.\n* A keyword list where the key are:\n  - An environment name such as `:dev` or `:test`.\n  - `:*` That will match any environment.\n  - `:override` which will declare the files as system overrides.\n\n  Values in keywords can be strings, lists, and nested keywords.","ref":"Nvir.html#dotenv!/1"},{"type":"function","title":"Examples - Nvir.dotenv!/1","doc":"import Config\n    import Nvir\n\n    # Load a single file\n    dotenv!(\".env\")\n\n    # Load multiple files\n    dotenv!([\".env\", \".env.#{config_env()}\"])\n\n    # Load files depending on environment\n    dotenv!(\n      *: \".env\",\n      dev: \".env.dev\",\n      test: \".env.test\"\n    )\n\n    # Load files with and without override\n    dotenv!(\n      dev: \".env\",\n      test: \".env\", \".env.test\",\n      override: [test: \".env.test.local\"]\n    )","ref":"Nvir.html#dotenv!/1-examples"},{"type":"function","title":"Nvir.env!/2","doc":"Returns the value of the given `var`, transformed and validated by the given\n`caster`.\n\nRaises if the variable is not defined or if the caster validation fails.\n\nPlease see the [README](README.md#available-casters) for available casters.","ref":"Nvir.html#env!/2"},{"type":"function","title":"Nvir.env!/3","doc":"Returns the value of the given `var`, transformed and validated by the given\n`caster`.\n\nReturns the `default` value if the variable is not defined.\n\nRaises if the caster validation fails.\n\nPlease see the [README](README.md#available-casters) for available casters.","ref":"Nvir.html#env!/3"},{"type":"module","title":"Nvir.Cast","doc":"Collection of casters for environment variables.","ref":"Nvir.Cast.html"},{"type":"function","title":"Nvir.Cast.cast/2","doc":"Casts an environment variable to the desired type.\n\nEnvironment variables are always defined as a string. Thus, the `cast/2`\nfunction will only work with strings as it's first argument.\n\nPlease refer to the \"Available Casters\" of the [README](README.md#available-casters) for a\ndetailed explanation of all casters.","ref":"Nvir.Cast.html#cast/2"},{"type":"type","title":"Nvir.Cast.caster/0","doc":"","ref":"Nvir.Cast.html#t:caster/0"},{"type":"type","title":"Nvir.Cast.result/0","doc":"","ref":"Nvir.Cast.html#t:result/0"},{"type":"module","title":"Nvir.Parser","doc":"A simple .env file parser.","ref":"Nvir.Parser.html"},{"type":"function","title":"Nvir.Parser.parse/2","doc":"Returns a list of `{key, value}` for all variables in the given content.\n\nThis function only parses strings, and will not attempt to read from the given\n`path`. The `path` variable is only useful to give more information when an\nerror is returned.\n\nEach returned value is either a string, or a function in the case of variable\ninterpolation. That function accepts a resolver calback that provides the\nvalue of previous variables.","ref":"Nvir.Parser.html#parse/2"},{"type":"function","title":"Resolver example - Nvir.Parser.parse/2","doc":"iex> file_contents = \"GREETING=$INTRO $WHO!\"\n    iex> {:ok, [{\"GREETING\", template}]} = Nvir.Parser.parse(file_contents)\n    iex> resolver = fn\n    ...>   \"INTRO\" -> \"Hello\"\n    ...>   \"WHO\" -> \"World\"\n    ...> end\n    iex> template.(resolver)\n    \"Hello World!\"\n\nWhen working with the system env you will likely use `&System.get_env(&1, \"\")`\nas a resolver. It is common to use an empty string for undefined system\nvariables, but you can of course raise from your function if it better suits\nyour needs.","ref":"Nvir.Parser.html#parse/2-resolver-example"},{"type":"type","title":"Nvir.Parser.buffer/0","doc":"","ref":"Nvir.Parser.html#t:buffer/0"},{"type":"type","title":"Nvir.Parser.key/0","doc":"","ref":"Nvir.Parser.html#t:key/0"},{"type":"type","title":"Nvir.Parser.parser/0","doc":"","ref":"Nvir.Parser.html#t:parser/0"},{"type":"type","title":"Nvir.Parser.resolver/0","doc":"","ref":"Nvir.Parser.html#t:resolver/0"},{"type":"type","title":"Nvir.Parser.template/0","doc":"","ref":"Nvir.Parser.html#t:template/0"},{"type":"type","title":"Nvir.Parser.value/0","doc":"","ref":"Nvir.Parser.html#t:value/0"},{"type":"type","title":"Nvir.Parser.variable/0","doc":"","ref":"Nvir.Parser.html#t:variable/0"},{"type":"exception","title":"Nvir.CastError","doc":"Exception defining an invalid cast. For instance with this env file:\n\n\n    NOT_AN_INT=some string\n\nCalling `Nvir.env!/2` with the `:integer!` caster will raise an\n`Nvir.CastError` exception.\n\n    Nvir.env!(\"NOT_AN_INT\", :integer!)","ref":"Nvir.CastError.html"},{"type":"exception","title":"Nvir.ParseError","doc":"Exception raised when `Nvir` failed to parse an env file.","ref":"Nvir.ParseError.html"},{"type":"extras","title":"Nvir","doc":"# Nvir\n\nEasy environment variables and Dotenv implementation for Elixir.\n\nThis library helps to load your \"dotenv\" files easily and provides validation\nfor environment variables.\n\nIt is a fork of [Dotenvy](https://github.com/fireproofsocks/dotenvy) that uses\nthe predefined system environment variables by default.","ref":"readme.html"},{"type":"extras","title":"Installation - Nvir","doc":"As usual, pull the library from your `mix.exs` file.\n\n```elixir\ndef deps do\n  [\n    {:nvir, \"~> 0.9\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic Usage - Nvir","doc":"You will generally use `Nvir` from your `config/runtime.exs` file.\n\n* Import the module functions, and call `dotenv!/1` to load your files.\n* Use `env!/2` to require a variable and validate it.\n* Use `env!/3` to provide a default value. Default values are not validated.\n\nNote that you do not have to call `dotenv!/1` to use the `env` functions. You can\nuse this library for validation only.\n\n```elixir\n# runtime.exs\n\n# Import the library\nimport Nvir\n\n# Load your env files for local development\ndotenv!([\".env\", \".env.#{config_env()}\"])\n\n# Configure your different services with the env!/2 and env!/3 functions.\nconfig :my_app, MyAppWeb.Endpoint,\n  secret_key_base: env!(\"SECRET_KEY_BASE\", :string!),\n  url: [host: env!(\"HOST\", :string!), port: 443, scheme: \"https\"]\n\nconfig :my_app, MyApp.Repo,\n  username: env!(\"DB_USERNAME\", :string!),\n  password: env!(\"DB_PASSWORD\", :string!),\n  database: env!(\"DB_DATABASE\", :string!),\n  # You can provide default values with env!/3\n  hostname: env!(\"DB_HOSTNAME\", :string!, \"localhost\"),\n  port: env!(\"DB_PORT\", :integer, 5432),\n  pool_size: env!(\"POOL_SIZE\", :integer, 10),\n  queue_target: env!(\"REPO_QUEUE_TARGET\", :integer, 50),\n  queue_interval: env!(\"REPO_QUEUE_INTERVAL\", :integer, 5000)\n\nconfig :my_app, Oban,\n  queues: [\n    emailing: env!(\"EMAILING_QUEUE_CONCURRENCY\", :integer, 10),\n  ]\n```\n\nThis is most of what you need to know to start using this library. Below is an\nadvanced guide that covers all configuration and usage options.","ref":"readme.html#basic-usage"},{"type":"extras","title":"Table of contents - Nvir","doc":"- [Installation](#installation)\n- [Basic Usage](#basic-usage)\n- [Table of contents](#table-of-contents)\n- [Loading files](#loading-files)\n  - [Single file](#single-file)\n  - [A list of files](#a-list-of-files)\n  - [Per environment files](#per-environment-files)\n- [The `env!` functions](#the-env-functions)\n  - [Requiring a variable](#requiring-a-variable)\n  - [Default values](#default-values)\n  - [Available Casters](#available-casters)\n  - [Custom Casters](#custom-casters)\n- [Overriding system variables](#overriding-system-variables)\n  - [File load order with overrides](#file-load-order-with-overrides)\n- [Mix Config environments](#mix-config-environments)\n  - [Defining the current environment](#defining-the-current-environment)\n- [Dotenv File Syntax Cheatsheet](#dotenv-file-syntax-cheatsheet)\n  - [Basic Syntax](#basic-syntax)\n  - [Comments](#comments)\n  - [Quoted Values](#quoted-values)\n  - [Multiline Strings](#multiline-strings)\n  - [Variable Interpolation](#variable-interpolation)\n- [Environment Files Inheritance](#environment-files-inheritance)\n  - [Rules for regular files](#rules-for-regular-files)\n  - [Examples](#examples)\n  - [Important Edge Case](#important-edge-case)\n  - [Rules for override files](#rules-for-override-files)","ref":"readme.html#table-of-contents"},{"type":"extras","title":"Loading files - Nvir","doc":"The `dotenv!/1` function accepts paths to files, either absolute or relative to `File.cwd!()` (which points to your app root where `mix.exs` is present).\n\nThere are different possible ways to chose what file to load.","ref":"readme.html#loading-files"},{"type":"extras","title":"Single file - Nvir","doc":"The classic dotenv experience.\n\n```elixir\ndotenv!(\".env\")\n```","ref":"readme.html#single-file"},{"type":"extras","title":"A list of files - Nvir","doc":"Non-existing files are safely ignored.  Your `.env` file will likely\nnot be present in production, and you may have a `.env.test` file but no\n`.env.dev` file.\n\n```elixir\ndotenv!([\".env\", \".env.#{config_env()}\"])\n```\n\nFiles are loaded in order. If a value is present in multiple files, the last\nfile wins.\n\nThe `config_env()` function is provided by `import Config` at the top of your config files.","ref":"readme.html#a-list-of-files"},{"type":"extras","title":"Per environment files - Nvir","doc":"When files are listed in a keyword list, the file is only loaded if the key matches the current environment.\n\nThis gives you more control on the files that are loaded, and ensures that no\nfile will be loaded in production if the env files are committed to git and/or\nincluded in your releases.\n\n```elixir\ndotenv!(\n  dev: \".env\",\n  test: [\".env\", \".env.test\"]\n)\n```\n\nAs you can see, keyword values can themselves be lists or strings. The files are\nloaded in order of appearance (as long as the environment matches). Just as\nabove, when a variable is defined in multiple files, the latter file has the\nfinal say on a variable's value.\n\nIt is also possible to pass the same key multiple times.\n\nFiles under a `:*` key are always loaded, regardless of the current\nenvironment. That key is mostly a syntax tool, as `[\"a\", key: \"b\"]` is valid\nElixir syntax, but `[key: \"a\", \"b\"]` is not.\n\nA wildcard key allows a file to be loaded in any environment:\n\n```elixir\ndotenv!(*: \".env\", test: \".env.test\")\n\n# Equivalent to\ndotenv!([\".env\", test: \".env.test\"])\n```\n\nThe following are **not** equivalent, as it changes the order of the files:\n\n```elixir\ndotenv!(*: \".env\", dev: \".env.dev\")\ndotenv!(dev: \".env.dev\", *: \".env\")\n```","ref":"readme.html#per-environment-files"},{"type":"extras","title":"The `env!` functions - Nvir","doc":"The `env!` functions allows you to load an environment variable and cast its\ncontent to the appropriate type.","ref":"readme.html#the-env-functions"},{"type":"extras","title":"Requiring a variable - Nvir","doc":"Calling `env!(var, caster)` will attempt to fetch the variable, just like\n`System.fetch_env!/1` does, cast its value, and return it.\n\nA `System.EnvError` exception will be raised if the variable is not defined.\n\nAn `Nvir.CastError` exception will be raised if the cast fails.","ref":"readme.html#requiring-a-variable"},{"type":"extras","title":"Default values - Nvir","doc":"Calling `env!(var, caster, default)` will use the default value if the key is\nnot defined.\n\nThe function will **not** use the default value if the cast of an existing key\nfails. This will still raise an `Nvir.CastError`.\n\nThe default value is not validated, so you can for instance call\n`env!(\"SOME_VAR\", :integer, :infinity)`, whereas `:infinity` is not a valid\ninteger.","ref":"readme.html#default-values"},{"type":"extras","title":"Available Casters - Nvir","doc":"Casters come into three flavors:\n\n* The \"value as is\" one.\n* The \"nil\" one with a `?` suffix that converts empty strings to `nil`. It will\n  however not fallback to the default value given to `env!/3` if the key exists.\n* The \"bang\" one with a `!` suffix that will raise an `Nvir.CastError` exception for\n  empty strings and special cases described below.\n\nIn some languages, using `null` where an integer is expected will cast the value\nto a \"default value\", generally `0` for integers. This is not the case in\nElixir. To respect that, casters for such types behave the same with and without\nthe `!` suffix. Namely, `:integer` and `:float` will raise for empty strings.\n\nIt is however not the case for `:existing_atom`, because the `:\"\"` atom is\ngenerally defined by the system long before an application starts, in Erlang\njust as in Elixir.\n\nEmpty strings occur when a variable is defined without a value:\n\n```\nHOST=localhost # value is \"localhost\"\nPORT=          # value is \"\"\n```\n\n#### String Casters\n\n| Caster | Description |\n|--------|-------------|\n| `:string` | Returns the value as-is. |\n| `:string?` | Converts empty strings to `nil`. |\n| `:string!` | Raises for empty strings. |\n\n#### Boolean Casters\n\n| Caster | Description |\n|--------|-------------|\n| `:boolean` | `\"false\"`, `\"0\"` and empty strings become `false`, any other value is `true`. Case insensitive. It is recommended to use `:boolean!` instead. |\n| `:boolean!` | Accepts only `\"true\"`, `\"false\"`, `\"1\"`, and `\"0\"`. Case insensitive. |\n\n#### Number Casters\n\n| Caster | Description |\n|--------|-------------|\n| `:integer!` | Strict integer parsing. |\n| `:integer?` | Like `:integer!` but empty strings becomes `nil`. |\n| `:float!` | Strict float parsing. |\n| `:float?` | Like `:float!` but empty strings becomes `nil`. |\n\n#### Atom Casters\n\n| Caster | Description |\n|--------|-------------|\n| `:atom` | Converts the value to an atom. Use the `:existing_atom` variants when possible. |\n| `:atom?` | Like `:atom` but empty strings becomes `nil`. |\n| `:atom!` | Like `:atom` but rejects empty strings. |\n| `:existing_atom` | Converts to existing atom only, raises otherwise. |\n| `:existing_atom?` | Like `:existing_atom` but empty strings becomes `nil`. |\n| `:existing_atom!` | Like `:existing_atom` but rejects empty strings. |\n\n#### Deprecated casters\n\nThose exist for legacy reasons and should not be used.\n\n| Caster | Description |\n|--------|-------------|\n| `:boolean?` | Same as `:boolean`. |\n| `:integer` | Same as `:integer!`. |\n| `:float` | Same as `:float!`. |","ref":"readme.html#available-casters"},{"type":"extras","title":"Custom Casters - Nvir","doc":"The second argument to `env!/2` and `env/3` also accept custom validators using an `fn`. The given function must return `{:ok, value}` or `{:error, message}` where `message` is a string.\n\n```elixir\nenv!(\"URL\", fn\n  \"https://\" <> _ = url -> {:ok, url}\n  _ -> {:error, \"https:// is required\"}\nend)\n```\n\nIt is also possible to return directly an error from `Nvir.cast/2`:\n\n```elixir\nenv!(\"PORT\", fn value ->\n  case Nvir.cast(value, :integer!) do\n    {:ok, port} when port > 1024 -> {:ok, port}\n    {:ok, port} -> {:error, \"invalid port: #{port}\"}\n    {:error, reason} -> {:error, reason}\n  end\nend)\n```","ref":"readme.html#custom-casters"},{"type":"extras","title":"Overriding system variables - Nvir","doc":"The files loaded by this library will not overwrite already existing variables. That is, as your `HOME` variable already exists, defining `HOME=/somewhere/else` in your `.env` file will have no effect.\n\nAnother special key can be given to `dotenv!/1` to override system variables:\n\n```elixir\ndotenv!([\".env\", override: \".env.local\"])\n\n# load more files\ndotenv!([\".env\", override: [\".env.local\", \".env.local.#{config_env()}\"]])\n```\n\nWith the code above, any variable from `.env` that does not already exists will be added to the system env, but _all_ variables from `.env.local` will be set.\n\nJust like environment specific keys, the `:override` key accepts strings or\nlists, and the lists may contain environments too. The following forms are\nequivalent:\n\n```elixir\ndotenv!(\n  *: [\".env\", override: \".env.local\"],\n  dev: [\".env.dev\", override: \".env.local.dev\"],\n  test: [\".env.test\", override: \".env.local.test\"]\n)\n\ndotenv!(\n  *: \".env\",\n  dev: \".env.dev\",\n  test: \".env.test\",\n  override: [*: \".env.local\", dev: \".env.local.dev\", test: \".env.local.test\"]\n)\n```\n\nThe `:*` key applies to all environments, and the files belong to the same group\nas files under a `:dev` or `:test` key. The final file in order still has the\nfinal say for a variable.\n\nThe two snippets above would both result in loading `\".env\"` and `\".env.dev\"` as regular files, and then `\".env.local\"` and `\".env.local.dev\"` as overrides, in those orders.","ref":"readme.html#overriding-system-variables"},{"type":"extras","title":"File load order with overrides - Nvir","doc":"Regular and override files are separated into two groups. As stated earlier,\neach group files are loaded in order of appearance, but all files from the\nregular files group are applied before loading the override files.\n\nThe `dotenv/1` function will do the following:\n\n* Load all regular files in order.\n* Patch system environment with non-existing keys.\n* Load all override files in order.\n* Overwrite system environment with all their values.\n\nThis means that the following expression will not load and apply `.env.local`\nbefore `.env` because they do not belong to the same group, and the `:override`\ngroup is applied last.\n\n```elixir\ndotenv!(override: \".env.local\", dev: \".env\")\n```","ref":"readme.html#file-load-order-with-overrides"},{"type":"extras","title":"Mix Config environments - Nvir","doc":"The list of possible environment names is not predefined. You can pass any key and the files will be loaded if that key matches the current environment.\n\nSo for instance it is possible to list files under a `:prod` key, while not recommended.\n\nSome projects use a dedicated environment for CI, so a custom `:ci` key can be used in this case.","ref":"readme.html#mix-config-environments"},{"type":"extras","title":"Defining the current environment - Nvir","doc":"The current environment that will match the keys given to `dotenv!/1` is the\nvalue of `config_env()` when called from a config file. Otherwise it is set to\nthe value of `Mix.env()`.\n\nIt is not recommended to call `dotenv!/1` directly from modules at runtime\nbecause the current environment will be undefined in a production release.\n`dotenv!/1` belongs to `runtime.exs`.","ref":"readme.html#defining-the-current-environment"},{"type":"extras","title":"Dotenv File Syntax Cheatsheet - Nvir","doc":"","ref":"readme.html#dotenv-file-syntax-cheatsheet"},{"type":"extras","title":"Basic Syntax - Nvir","doc":"```bash\n# Simple assignment\nKEY=value\n\n# With spaces around =\nKEY = value\n\n# Empty value\nEMPTY=\nEMPTY=\"\"\nEMPTY=''\n\n# The parser will ignore an \"export\" prefix\nexport KEY=value\n```","ref":"readme.html#basic-syntax"},{"type":"extras","title":"Comments - Nvir","doc":"Comments are supported on their own line or at the end of a line.\n\n**Important**, when a value is not quoted, the comment `#` character must be\nseparated by at least one space, otherwise the comment will be included in the\nvalue.\n\n```bash\n# This is a comment on it's own line\n\nKEY=value # Inline comment\n\nKEY=value# No preceding space, this is part of the value\n```","ref":"readme.html#comments"},{"type":"extras","title":"Quoted Values - Nvir","doc":"* Quotes are optional.\n* Double quotes let you write escape sequences.\n* Single quotes define verbatim values. No escaping is done except for the\n  single quote itself.\n\n#### Raw Strings\n```bash\nKEY=raw value with spaces\n```\n\n#### Double Quotes\n```bash\nKEY=\"value with spaces\"\nKEY=\"escape \\\"quotes\\\" inside\"\nKEY=\"supports \\n \\r \\t \\b \\f escapes\"\n```\n\n#### Single Quotes\n```bash\nKEY='value with spaces'\nKEY='no escapes \\n' # value will have a \"\\\" character followed by a \"n\".\nKEY='escape \\'quotes\\' inside'\n```","ref":"readme.html#quoted-values"},{"type":"extras","title":"Multiline Strings - Nvir","doc":"The same rules applies for escaping as in single line values:\n\n* Double quotes let you write escape sequences.\n* Single quotes define verbatim values. No escaping is done except for the\n  single quote itself.\n\n\n#### Triple Double Quotes\n\n```bash\nKEY=\"\"\"\nLine 1\nLine 2 with \"quotes\"\n\"\"\"\n```\n\n#### Triple Single Quotes\n\n```bash\nKEY='''\nLine 1\nLine 2 with 'quotes'\n'''\n```","ref":"readme.html#multiline-strings"},{"type":"extras","title":"Variable Interpolation - Nvir","doc":"`Nvir` supports variable interpolation within env files. Please refer to the\n\"Environment Files Inheritance\" section for more details on which value is used\non different setups.\n\n```bash\n# This variable can be used below in the same file\nGREETING=Hello\n\n# Basic syntax\nMSG=$GREETING World\n\n# Enclosed syntax\nMSG=${GREETING} World\n\n# Not interpolated (single quotes)\nMSG='$GREETING World'\n\n# In raw values, a comment without a preceding space will be included in the\n# value\nMSG=$GREETING# This is part of the value\nMSG=${GREETING}# This too\nMSG=$GREETING # Actual comment\n```","ref":"readme.html#variable-interpolation"},{"type":"extras","title":"Environment Files Inheritance - Nvir","doc":"","ref":"readme.html#environment-files-inheritance"},{"type":"extras","title":"Rules for regular files - Nvir","doc":"These rules apply to the regular group. Override files will always have their values added to system environment.\n\n1. System environment variables always take precedence over env files\n2. Multiple env files can be loaded in sequence, with later files overriding\n   earlier ones\n3. Variable interpolation (`$VAR`) uses values from the system first, then from\n   the most recently defined value","ref":"readme.html#rules-for-regular-files"},{"type":"extras","title":"Examples - Nvir","doc":"```elixir\n# System state:\n# WHO=moon\n\n# .env\nWHO=world\nHELLO=hello $WHO   # Will use WHO=moon from system\n\n# Result:\n# HELLO=hello moon\n```\n\nWith multiple files, we use the latest value. In this exemple the variable is\nnot already defined in the system:\n\n```elixir\n# .env\nWHO=world\n\n# .env.dev\nWHO=mars\nHELLO=hello $WHO\n\n# .env.dev.2\nWHO=moon\nHELLO=hello $WHO\n\n# Loading order: .env -> .env.dev -> .env.dev.2\n# Result:\n# WHO=moon\n# HELLO=hello moon\n```","ref":"readme.html#examples"},{"type":"extras","title":"Important Edge Case - Nvir","doc":"When a variable using interpolation is not redefined in subsequent files, it keeps using the value from when it was defined.\n\n```elixir\n# .env\nWHO=world\n\n# .env.dev\nWHO=mars\nHELLO=hello $WHO    # HELLO is defined here, uses WHO=mars\n\n# .env.dev.2\nWHO=moon           # WHO is updated, but HELLO keeps its value\n                   # since it's not redefined here\n\n# Final result:\n# WHO=moon\n# HELLO=hello mars  # Not \"hello moon\"!\n```\n\nThis may cause inconsistencies if you code depends on the values of both `HELLO` and `WHO`.","ref":"readme.html#important-edge-case"},{"type":"extras","title":"Rules for override files - Nvir","doc":"Override files follow the same logic, each file overrides the previous ones.\n\nThe only difference is that the values in the files take precedence over any\npreexisting variable in the system environment.\n\nThe edge case documented above still applies.","ref":"readme.html#rules-for-override-files"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}